WidgetsInTemplateMixin.js

# WidgetsInTemplateMixin

This test shows that a _AttachMixin dijit with _WidgetsInTemplate properly attaches widgets from the template.

##

This tests that nodes inside of data-dojo-attach-point="containerNode" are ignored

## heading

supporting widget
contained widget
<div> <div data-dojo-attach-point="normalNode">normal node</div> <button data-dojo-attach-point="buttonWidget" data-dojo-attach-event="click:onClick" data-dojo-type="dijit/form/Button">button #1</button> <div data-dojo-attach-point="checkboxWidget" data-dojo-attach-event="click:onClick" data-dojo-type="dijit/form/CheckBox"></div> checkbox #1 <div data-dojo-attach-point="progressBarWidget" data-dojo-attach-event="change:onClick" data-dojo-type="dijit/ProgressBar" data-dojo-props='value: 20, maximum: 200, style: "width:400px;"'></div> </div>
<div> <div data-dojo-attach-point="checkboxWidget" data-dojo-type="dijit/form/CheckBox"></div> checkbox #3 <div data-dojo-attach-point="containerNode"></div> </div>
hello world this is my
and some more
<div> <div data-dojo-type="TestLayoutWidget" data-dojo-attach-point="layout"> <div data-dojo-type="TestCtndWidget" data-dojo-attach-point="layChild1"></div> <div data-dojo-type="TestCtndWidget" data-dojo-attach-point="layChild2"></div> </div> <div data-dojo-type="TestCtnrWidget" data-dojo-attach-point="container"> <div data-dojo-type="TestCtndWidget" data-dojo-attach-point="contained1"></div> <div data-dojo-type="TestCtndWidget" data-dojo-attach-point="contained2"></div> </div> <div data-dojo-type="TestStubWidget" data-dojo-attach-point="stub1"></div> <div data-dojo-type="TestNonCtnrWidget" data-dojo-attach-point="nonContainer"> <div data-dojo-type="TestStubWidget" data-dojo-attach-point="nonContained1"></div> <div data-dojo-type="TestStubWidget" data-dojo-attach-point="nonContained2"></div> </div> <div data-dojo-type="TestCtnrWidget" data-dojo-attach-point="threeLevel"> <div data-dojo-type="TestNonCtnrWidget" data-dojo-attach-point="secondLevel"> <div data-dojo-type="TestStubWidget" data-dojo-attach-point="bottomLevel"></div> </div> </div> <div data-dojo-type="TestNonCtnrWidget" data-dojo-attach-point="anotherThree"> <div data-dojo-type="TestCtnrWidget" data-dojo-attach-point="anotherSecond"> <div data-dojo-type="TestCtndWidget" data-dojo-attach-point="anotherBottom"></div> </div> </div> </div>
<div> <div data-dojo-type="dijit/form/TextBox" data-dojo-attach-point="textbox" data-dojo-attach-event="onClick: handleClick"></div> </div>